<?php
/**
 Plugin Name: Recommended Reading: Google Reader Shared
 Plugin URI: http://www.cmurrayconsulting.com/software/google-reader-shared-wordpress
 Description: Pulls shared items from your <strong>Google Reader</strong> account for display in a <strong>sidebar widget</strong> or within pages or posts. Easily customized with friendly interface. <strong>Embed in page or post</strong> via shortcode; can always show newest, or start at post publication date!
 Version: 3.2
 Author: Jacob M Goldman (C. Murray Consulting)
 Author URI: http://www.cmurrayconsulting.com

    Plugin: Copyright 2009 C. Murray Consulting  (email : jake@cmurrayconsulting.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


//******************//
//REQUIREMENTS CHECK//
//******************//

function req_check () {
  if(!class_exists('SimpleXmlElement')) {
  	echo '<p>A version of PHP with the <a href="http://php.net/simplexml" target="_blank">SimpleXML class</a> is required. This is included with PHP 5 and newer.</p>';
    return false;
  } elseif (!ini_get('allow_url_fopen') && !function_exists("curl_init")) {
  	echo '<p><strong>Host Limitation Found</strong></p><p>Recommended Reading needs to load a foreign XML feed from Google. Your host has turned off support for "<a href="http://www.php.net/function.fopen" target="_blank">fopen</a>" and <a href="http://us3.php.net/manual/en/intro.curl.php" target="_blank">cURL</a> - the two most widely supported mechanisms for loading foreign information like your shared feed. Please contact your host and ask them to enable the cURL PHP module or add "allow_url_fopen" in your PHP configuration.</p>';
  	return false;
  }
  return true;
}

//*********//
//PLUG INIT//
//*********//
function grs_admin_init() {
	register_setting('grs-options', 'gr_lastupdate');
	register_setting('grs-options', 'gr_sc_lastupdate');
	register_setting('grs-options', 'gr_credit');
	register_setting('grs-options', 'gr_sid');
	register_setting('grs-options', 'gr_num');
	register_setting('grs-options', 'gr_content');
	register_setting('grs-options', 'gr_trim');
	register_setting('grs-options', 'gr_notes');
	register_setting('grs-options', 'gr_date');
	register_setting('grs-options', 'gr_datep');
	register_setting('grs-options', 'gr_source');
	register_setting('grs-options', 'gr_sourcep');
	register_setting('grs-options', 'gr_open');
	register_setting('grs-options', 'gr_notep');
	register_setting('grs-options', 'gr_skipnote');
	register_setting('grs-options', 'gr_sc_styles');
	register_setting('grs-options', 'gr_sc_html');
	register_setting('grs-options', 'gr_sc_trim');
	register_setting('grs-options', 'gr_sc_strpimg');
	register_setting('grs-options', 'gr_sc_simplehtml');
	register_setting('grs-options', 'gr_nofollow');
	register_setting('grs-options', 'gr_sc_cache');
	register_setting('grs-options', 'gr_cache');
	register_setting('grs-options', 'gr_publish_date');
	register_setting('grs-options', 'gr_publish_upto');
}
add_action( 'admin_init', 'grs_admin_init' );

//*******************//
//***CORE FUNCTION***//
//*******************//

function google_reader_items($isshortcode = false, $maxcnt = '') {
	if (!req_check()) return false;

	//handling of posts that should only show posts older than publication date of post
	$gr_publish_date = ($isshortcode) ? get_option("gr_publish_date") : false;
	if($gr_publish_date) {
		$cache = get_post_meta(get_the_ID(),"_gr_cache",true);
		if ($cache) return $cache; //WE'RE ALREADY DONE!
		$post_date = get_the_time('U');
		$gr_publish_upto = get_option("gr_publish_upto");
		if($gr_publish_upto) {
			//get last post using rec reading pub date
			global $wpdb;
			$mysql_date = date ("Y-m-d H:i:s", $post_date);
			$last_post = $wpdb->get_row("SELECT post_date FROM $wpdb->posts WHERE post_date < '$mysql_date' AND (post_type = 'post' OR post_type = 'page') AND post_content LIKE '%[recreading%]%' ORDER BY post_date DESC LIMIT 1;", ARRAY_N);
			$gr_publish_upto = ($last_post[0]) ? strtotime($last_post[0]) : false;
		}
	}
	
	$gr_sid = get_option("gr_sid");
	if (!$gr_sid) return '<a href="http://www.cmurrayconsulting.com/software/google-reader-shared-wordpress/" target="_blank">Recommended Reading plug-in</a> has not been configured.';
	
	$url = "http://www.google.com/reader/public/atom/user%2F".$gr_sid."%2Fstate%2Fcom.google%2Fbroadcast";
	if (function_exists("curl_init")) {
		//use curl - faster
		$ch = curl_init($url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_HEADER, 0);
		$data = curl_exec($ch);
		$response = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		curl_close($ch);
	} else {
		//use fopen - fallback
		$data = @file_get_contents($url);
		$response = explode(" ",$http_response_header[0],3);
		$response = $response[1];		
	}
	if ($response != "200") return "No Google Reader feed was found with the provided ID.";
	$doc = new SimpleXmlElement($data, LIBXML_NOCDATA);
	
	//basic caching handling
	$feedupdate = strtotime($doc->updated);
	$lastupdate = $isshortcode ? get_option("gr_sc_lastupdate") : get_option("gr_lastupdate"); //whether to use shortcode cache check or widget cache check
	
	if(!$lastupdate || $lastupdate < $feedupdate) {
		if (isset($gr_publish_upto) && $gr_publish_upto) $maxcnt = '';  //if using publish up to and it applies, set max count to all
		elseif (!$maxcnt) $maxcnt = get_option("gr_num");  //otherwise if it wasn't passed by shortcode, get from options
		$cnt = count($doc->entry); //count total number of entries in feed 
		if (!$cnt) return "There are no items in your shared Google Reader feed.";
		if ($maxcnt && $maxcnt < $cnt) $cnt = $maxcnt;	//if user specified number of entries (and its less than total), here's the max loop iterations
		
		$gr_open = get_option("gr_open") ? ' target="_blank"' : ' ';	//HTML for opening link in new window if set to
		$gr_nofollow = get_option("gr_nofollow") ? ' rel="nofollow"' : ' ';	//HTML for nofollow rel
		$gr_skipnote = get_option('gr_skipnote');
		
		$gr_date = get_option("gr_date");
		if($gr_date) $datep = get_option("gr_datep");
		$gr_source = get_option("gr_source");
		if ($gr_source) $sourcep = get_option("gr_sourcep");
		$gr_notes = get_option("gr_notes");
		if($gr_notes) $notep = get_option("gr_notep");
		$gr_content = get_option("gr_content");
		if ($gr_content) $desctrim = get_option("gr_trim");
		if ($isshortcode) {
			$gr_sc_html = get_option('gr_sc_html');
			$gr_sc_simplehtml = get_option('gr_sc_simplehtml');
			if (get_option('gr_sc_trim')) $desctrim = "";
			$gr_sc_strpimg = get_option('gr_sc_strpimg');
		}
		
		$gr_cache = '<ul class="gReader-list">';
		
		$p=0; //counter of shown posts
		$i=0; //current child index in xml
		$totali = count($doc->entry);
		
		while ($p<$cnt && $i<$totali) {
			$date_published = strtotime($doc->entry[$i]->published." ".get_option('gmt_offset')); //convert feed published date to usable timestamp factoring in GMT
						
			//if its shortcode and we only want to show items older than our date of publication, skip newer items
			if ($gr_publish_date && $date_published > $post_date) {
				$i++;
				continue;	
			}
			//if using 'up till last post' option, make sure current item is newer than last post
			if ($gr_publish_date && $gr_publish_upto && $date_published <= $gr_publish_upto) {
				if ($p==0) $gr_cache .= '<li>No items have been shared since the last post to feature shared items.</li>'; //if no items since last post, show a message
				break;
			}
			
			$urlPost = $doc->entry[$i]->link->attributes();
			$urlPost = $urlPost->href; //fix for fatal PHP4 error
			
			//check if its a standalone shared note
			if ($gr_skipnote && strstr($urlPost,"google.com/reader/item")) {
				$cnt = $cnt+1;
				continue;
			}
			
			$title 	= $doc->entry[$i]->title;
			
			$gr_cache .= '<li class="gReader-item gReader-item-'.$i.'">';
			$gr_cache .= '<a href="'.$urlPost.'" title="link to post"'.$gr_open.$gr_nofollow.' class="gReader-title">'.$title.'</a>';
			if ($gr_date) {
				$gr_cache .= '<div class="gReader-date">';
				if($datep) $gr_cache .= '<span class="preface">'.$datep.' </span>';
				$gr_cache .= date($gr_date,$date_published).'</div>';				
			}
			if ($gr_source) {
				$postsource = $doc->entry[$i]->source->title;
				$postsourcelink = $doc->entry[$i]->source->link->attributes();
				$postsourcelink = $postsourcelink->href; //php4 workaround
				
				if ($postsource == "(title unknown)") $postsource = "My Shared Items";  //for stand alone shared note
				
				$gr_cache .= '<div class="gReader-source">';
				if($sourcep) $gr_cache .= '<span class="preface">'.$sourcep.' </span>';
				$gr_cache .= '<a href="'.$postsourcelink.'"'.$gr_open.'title="source blog">'.$postsource.'</a></div>';	
			}
			if ($gr_notes) {
				$gs_ns = $doc->entry[$i]->children('http://www.google.com/schemas/reader/atom/');
				if (isset($gs_ns->annotation)) {
					$annotation = $gs_ns->annotation->children();
					$annotation = $annotation->content; //php4 fatal error work around
					if ($notep) $notep = '<span class="preface">'.$notep.' </span>';
					$gr_cache .= '<div class="gReader-notes">'.$notep.strip_tags($annotation).'</div>';
				}
			}
			if ($gr_content) {
				$desc = isset($doc->entry[$i]->content) ? $doc->entry[$i]->content : $doc->entry[$i]->summary;	//content may be stored in content tag or summary tag depending on blog
				
				if (substr($desc,0,4) == "<blo") $desc = substr($desc, strpos($desc,"</blo")); //remove inline shared item note
				
			 	if ($isshortcode && $gr_sc_html && !$desctrim) {
			 		if ($gr_sc_simplehtml) $desc = strip_tags($desc,"<a><strong><b><em><i><blockquote><p><br>");
	 				elseif ($gr_sc_strpimg) $desc = preg_replace('#</?img[^>]*>#is','',$desc);
			 	} else {
	 				$desc = preg_replace('/&[^;]+;/','',strip_tags($desc));
	 				if($desctrim && strlen($desc) > $desctrim) $desc = trim(substr($desc,0,$desctrim))."...";	//shorten content if shorter than defined max length
 				}
			 	 
				$gr_cache .= '<div class="gReader-desc">'.$desc.'</div>';
			}
			$gr_cache .= '</li>';
			
			$i++;
			$p++;
		}
		
		if (get_option("gr_credit")) $gr_cache .= '<li class="grCredit"><small>Plugin by <a href="http://www.cmurrayconsulting.com/software/google-reader-shared-wordpress/" title="Expert WordPress Developers"'.$gr_open.'>C. Murray Consulting</a></small></li>';
		
		$gr_cache .= "</ul>";
		
		if($isshortcode && $gr_publish_date) {
			//if its based on post date and we'll have multiple, we store the value in the post meta
			update_post_meta(get_the_ID(),"_gr_cache",$gr_cache);
			//FINISH UP
			return $gr_cache;
		} elseif ($isshortcode) {
			update_option('gr_sc_cache',$gr_cache);
			update_option('gr_sc_lastupdate',$feedupdate);
		} else {
			update_option('gr_cache',$gr_cache);
			update_option('gr_lastupdate',$feedupdate);
		}
	}
	
	if ($isshortcode) return get_option("gr_sc_cache"); //shortcode needs return instead of echo
	
	return get_option("gr_cache");
}

//****************************//
//*** WIDGET INITIALIZATION **//
//****************************//

function widgetGRS_control() {
	// We need to grab any preset options
	$options = get_option("setup_widget_grs");
	if (!is_array( $options )) $options = array('title' => 'Recommended Reading'); // No options? No problem! We set them here.

	if (isset($_POST['widgetGRS-Submit'])) {
		$options['title'] = htmlspecialchars($_POST['widgetGRS-WidgetTitle']);
		update_option("setup_widget_grs", $options); // And we also update the options in the Wordpress Database
	}
	
	echo '
		<label for="widgetGRS-WidgetTitle">Widget Title:</label>
		<input type="text" id="widgetGRS-WidgetTitle" name="widgetGRS-WidgetTitle" value="'.$options['title'].'" />
		<input type="hidden" id="widgetGRS-Submit" name="widgetGRS-Submit" value="1" />
	';
} 

function widget_grs($args) {
	extract($args);  
	$options = get_option("setup_widget_grs");  
  	if (!is_array( $options )) $options = array('title' => 'Recommended Reading');
	if (!$options['title']) $options['title'] = "Recommended Reading"; 
  	
	echo $before_widget;
	echo $before_title.$options['title'].$after_title;  
	echo google_reader_items();  
	echo $after_widget;  
}

function grs_init() {
  register_sidebar_widget('Rec. Reading', 'widget_grs');
  register_widget_control('Rec Reading', 'widgetGRS_control');
}
add_action("plugins_loaded", "grs_init");

//************************//
//** ADMIN CONTROL PANEL *//
//************************//

function grs_admin_menu() {
	add_options_page('Google Reader Shared Posts Configuration', 'Rec. Reading', 8, __FILE__, 'grs_options');
}
add_action('admin_menu', 'grs_admin_menu');

//** SET DEFAULTS **/
function set_grs_options() {
	update_option('gr_credit', true);
}
register_activation_hook(__FILE__,'set_grs_options');

//** ADMIN CONTROL PANEL PAGE **//

function grs_options() { 
	if ($_GET['updated'] == 'true') {
		update_option("gr_lastupdate",""); // clear the cache when editing the options
		update_option("gr_sc_lastupdate",""); // clear the shortcode cache when editing the options
		
		//clear shortcode cache
		if(get_option("gr_publish_date")) {
			global $wpdb; 
			$wpdb->query("DELETE FROM $wpdb->postmeta WHERE meta_key = '_gr_cache';");
		}
	}
	?>
	<script type="text/javascript" language="javascript">
		function isValidEmail(str) {
			return (str.lastIndexOf(".") > 2) && (str.indexOf("@") > 0) && (str.lastIndexOf(".") > (str.indexOf("@")+1)) && (str.indexOf("@") == str.lastIndexOf("@"));
		} 
		
		function makeRequest(idCheck) {
			//default value for idCheck
			if (typeof idCheck == "undefined") idCheck=false;
		   	  	
			if (idCheck) {
			  	var googleID = jQuery('#gr_sid').val();
			  	if(googleID.length != 20 || isNaN(googleID)) {
			  		jQuery('#message').html("<p><strong>Not a valid Google ID.</strong></p>").fadeIn('slow');
					jQuery('#gr_sid').animate( { backgroundColor: '#FFCCCC' }, 'slow').focus();
			  		return false;
			  	}
			  	
				jQuery('#message').html("<p><strong>Please wait... confirming valid Google Reader ID.</strong></p>").fadeIn("slow");
			} else {
				//confirm an email has been entered
	    		var gEmail = jQuery('#gr_un').val();
				if(isValidEmail(gEmail) == false) {
					alert('Enter a valid email address used for your Google account.');
					jQuery('#gr_un').focus();
					return false;
				}
		  		
		  		//confirm a password was entered
				var gPasswd = jQuery('#gr_pw').val();
		  		if(gPasswd == "") {
				  	alert('Please enter your account password.');
					jQuery('#gr_pw').focus();
					return false;
				}
		  		
		  		//let the user know we're loading it
		  		jQuery('#message').html("<p><strong>Please wait... attempting to find your Google Reader ID.</strong></p>").fadeIn("slow");
				jQuery('#gr_sid').val("(loading)")
				.animate( { backgroundColor: '#FFFBCC' }, "slow" );
			}
	   	
			var url = "<?php echo WP_PLUGIN_URL; ?>/<?php echo basename(dirname(__FILE__)); ?>/getsid.php";
			if(idCheck) jQuery.get(url, { gID: googleID }, function(data) { handle_sid(data); });	
			else jQuery.get(url, { Email: gEmail, Passwd: gPasswd }, function(data) { handle_sid(data); });
		}
	
		function handle_sid(sidResponse) {
			if(sidResponse == "g0") {
				jQuery('#message').html("<p><strong>Google Reader ID was not valid, or you have no shared items in your feed.</strong></p>").fadeIn('slow');
  				jQuery('#gr_sid').animate( {backgroundColor: '#FFCCCC'}, 'slow');
            } else if(sidResponse == "g1") {
           		jQuery('#message').html("<p>Successfully validated ID!</p>").fadeIn('slow');
  				jQuery('#gr_sid').animate( {backgroundColor: '#83F52C'}, 'slow');
            } else if(sidResponse == "0") {
				jQuery('#message').html("<p><strong>Google Reader account was not found, or there was an error trying to get user account information.</strong></p>").fadeIn('slow');
  				jQuery('#gr_sid').animate( {backgroundColor: '#FFCCCC'}, 'slow').val("");
	   		} else {
	   			jQuery('#message').fadeOut('slow');
  				jQuery('#gr_sid').animate( {backgroundColor: '#83F52C'}, 'slow').val(sidResponse);            
      		}
	   	}
	   
	   	function setMode(theMode) {
	   		if (typeof theMode == "undefined") theMode = 1;
  		  
			if (theMode == 1) {
  		  		jQuery('#gr_num').val("5");
				jQuery('#gr_content').attr('checked', false);
	        	jQuery('#gr_trim').val("");
	        	jQuery('#gr_date').val("");
	        	jQuery('#gr_datep').val("");
	        	jQuery('#gr_source').attr('checked', false);
	        	jQuery('#gr_sourcep').val("By");
	        	jQuery('#gr_open').attr('checked', true);
	        	jQuery('#gr_notes').attr('checked', false);
	        	jQuery('#gr_notep').val("");
	        	jQuery('#gr_nofollow').attr('checked', true);
	        } else {
  		  		jQuery('#gr_num').val("3");
		        jQuery('#gr_content').attr('checked', true);
		        jQuery('#gr_trim').val("210");
		        jQuery('#gr_date').val("F j, Y");
		        jQuery('#gr_datep').val("Published:");
		        jQuery('#gr_source').attr('checked', true);
		        jQuery('#gr_sourcep').val("Source:");
		        jQuery('#gr_open').attr('checked', true);
		        jQuery('#gr_notes').attr('checked', true);
		        jQuery('#gr_notep').val("My Note: ");
		        jQuery('#gr_nofollow').attr('checked', true);
			}
	  	}
	</script>


	<div class="wrap">
		<div class="icon32" style="background: transparent url(<?php echo WP_PLUGIN_URL; ?>/<?php echo basename(dirname(__FILE__)); ?>/images/gr_icon.png) 3px 3px no-repeat;"><br /></div>
		<h2>Recommended Reading: Google Reader Shared Configuration</h2>
	
		<div class="updated" id="message" style="display: none;"></div>

		<div id="poststuff" style="margin-top: 20px;">
	
		<?php if (!req_check()) return false; ?>
	
		<div class="postbox" style="width: 215px; min-width: 215px; float: right;">
			<h3 class="hndle">Support us</h3>
			<div class="inside">
				<p>Help support continued development of Recommended Reading and other plugins.</p>
				<p>The best thing you can do is refer someone looking for web development or strategy work <a href="http://www.cmurrayconsulting.com">to our company</a>.</p>
				<p>Short of that, here are other ways you can help:</p>
				<form method="post" action="https://www.paypal.com/cgi-bin/webscr" style="text-align: left;">
				<input type="hidden" value="_s-xclick" name="cmd"/>
				<input type="hidden" value="3377715" name="hosted_button_id"/>
				<input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donate_LG.gif" name="submit" alt="PayPal - The safer, easier way to pay online!"/> <img height="1" border="0" width="1" alt="" src="https://www.paypal.com/en_US/i/scr/pixel.gif"/><br/>
				</form>
				<form method="post" action="options.php">
				<?php settings_fields('grs-options'); ?>
				<p><input type="checkbox" name="gr_credit" id="gr_credit"<?php if (get_option('gr_credit')) { echo ' checked="true"'; } ?> /> Include link to us [<a href="#" onclick="alert('Inserts a small link back to our site at the bottom of the output'); return false;" style="cursor: help;" title="Inserts a small link back to our site at the bottom of the output">?</a>]</p>
				<p><strong><a href="http://www.cmurrayconsulting.com/software/google-reader-shared-wordpress/">Support page</a></strong></p>
			</div>
		</div>

		<div class="postbox" style="width: 350px;">
			<h3 class="hndle">My Google Reader ID</h3>
			<div class="inside">
				<table class="form-table" style="clear: none;" >
					<tr valign="top">
						<th scope="row">Google Reader ID [<a href="#" onclick="alert('Google Reader assigns a unique, 20 digit numeric ID to each user. To manually find the ID, open Google Reader, and click the Shared Items option, below Your Stuff, in the left navigation. Focus on the URL of the page: the numeric ID at the end, just after %2F, is your unique ID.'); return false;" style="cursor: help;">?</a>]</th>
						<td><input type="text" name="gr_sid" id="gr_sid" value="<?php echo get_option('gr_sid'); ?>"  /></td>
					</tr>
					<tr valign="top">
						<th scope="row"></th>
						<td><input type="button" value="Validate ID" onclick="makeRequest(1)" class="button" /></td>
					</tr>
					
					<tr valign="top">
						<th scope="row" valign="top" colspan="2" style="border-top: 1px dashed #DFDFDF; padding-top: 15px;"><strong>Look up my Google Reader ID</strong></th>
					</tr>
					
					<?php if (function_exists(curl_init)) { ?>
					<tr valign="top">
						<th scope="row">Google Username</th>
						<td><input type="text" name="gr_un" id="gr_un" value="<?php echo get_option('gr_un'); ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row">Google Password</th>
						<td><input type="password" name="gr_pw" id="gr_pw" value="<?php echo get_option('gr_pw'); ?>" /></td>
					</tr>
					<tr valign="top">
						<th scope="row"></th>
						<td><input type="button" value="Get ID" onclick="makeRequest()" class="button" /></td>
					</tr>
					<?php } else { ?>
					<tr valign="top">
						<td colspan="2">Your server does not have <a href="http://www.php.net/manual/en/intro.curl.php" target="_blank">cURL</a> enabled. cURL is a widely supported PHP module used to load and process external web pages behind the scenes. Unfortunately, cURL support is needed to dynamically look up your ID. You may still manually find and enter your ID. Click the question mark link above for instructions.</td>
					</tr>
					<?php } ?>
				</table>
			</div>
		</div>
	
	<div class="postbox" style="width: 350px;">
		<h3 class="hndle">Display Settings</h3>
		<div class="inside">
			<table class="form-table">
				<tr valign="top">
					<th scope="row" valign="top">Quick Set</th>
					<td>
						<input type="button" value="Simple" onclick="setMode(1)" class="button" />
						<input type="button" value="Detailed" onclick="setMode(2)" class="button" />
					</td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top">Number of Posts [<a href="#" onclick="alert('Leave this field blank or set it to 0 to show all items. Keep in mind that, depending on the number of items shared, this may have performance implications.'); return false;" style="cursor: help;">?</a>]</th>
					<td><input type="text" name="gr_num" id="gr_num" value="<?php echo get_option('gr_num'); ?>" /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top" style="border-top: 1px dashed #DFDFDF;">Show Post Content [<a href="#" onclick="alert('Show the actual body of the shared item.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 10px; border-top: 1px dashed #DFDFDF;"><input type="checkbox" name="gr_content" id="gr_content"<?php if (get_option('gr_content')) { echo ' checked="true"'; } ?> /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top">Truncate Content [<a href="#" onclick="alert('Enter the number of characters you want to show from the post content / body. Leave it blank or set to 0 to show the entire post.'); return false;" style="cursor: help;">?</a>]</th>
					<td><input type="text" name="gr_trim" id="gr_trim" value="<?php echo get_option('gr_trim'); ?>" /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top" style="border-top: 1px dashed #DFDFDF;">Show Date [<a href="#" onclick="alert('Show and format date of post. Leave it blank to hide the date. If used, must be in PHP date format.'); return false;" style="cursor: help;">?</a>]</th>
					<td valign="top" style="border-top: 1px dashed #DFDFDF;">
						<input type="text" name="gr_date" id="gr_date" value="<?php echo get_option('gr_date'); ?>" style="width: 80px;" />	<input type="button" value="Reset" onclick="jQuery('#gr_date').val('F j, Y');" class="button" /><br />
						<span class="howto">Use <a href="http://php.net/date" rel="help" target="_blank">PHP date format</a>.</span>
					</td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top">Preface Date [<a href="#" onclick="alert('Optional text to show before the date (eg. Published On)'); return false;" style="cursor: help;">?</a>]</th>
					<td><input type="text" name="gr_datep" id="gr_datep" value="<?php echo get_option('gr_datep'); ?>" /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top" style="border-top: 1px dashed #DFDFDF;">Show Blog Source [<a href="#" onclick="alert('Show the name of the blog or feed this came from, with a link.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 10px; border-top: 1px dashed #DFDFDF;"><input type="checkbox" name="gr_source" id="gr_source"<?php if (get_option('gr_source')) { echo ' checked="true"'; } ?> /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top">Preface Source [<a href="#" onclick="alert('Optional text to show before the source (i.e. Source)'); return false;" style="cursor: help;" title="Optional text to show before the source (i.e. Source)">?</a>]</th>
					<td><input type="text" name="gr_sourcep" id="gr_sourcep" value="<?php echo get_option('gr_sourcep'); ?>" /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top" style="border-top: 1px dashed #DFDFDF;">Open Links in New Window</th>
					<td style="padding-top: 10px; border-top: 1px dashed #DFDFDF;"><input type="checkbox" name="gr_open" id="gr_open"<?php if (get_option('gr_open')) { echo ' checked="true"'; } ?> /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top">rel="nofollow" [<a href="#" onclick="alert('Adds this attribute and value to links; instructs some search engines not to influence ranking of the target in search engine index.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 10px;"><input type="checkbox" name="gr_nofollow" id="gr_nofollow"<?php if (get_option('gr_nofollow')) { echo ' checked="true"'; } ?> /></td>
				</tr>
			</table>
		</div>
	</div>
	
	<div class="postbox" style="width: 350px;">
		<h3 class="hndle">Shared Item Notes</h3>
		<div class="inside">
			<table class="form-table">
				<tr valign="top">
					<th scope="row" valign="top">Show Notes [<a href="#" onclick="alert('Google Reader lets you attach notes to shared items. This lets you display those notes. In the current version, this will not affect stand alone notes in your feed.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 10px;"><input type="checkbox" name="gr_notes" id="gr_notes"<?php if (get_option('gr_notes')) { echo ' checked="true"'; } ?> /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top">Preface Note [<a href="#" onclick="alert('Optional text to show before the note (i.e. My Notes)'); return false;" style="cursor: help;">?</a>]</th>
					<td><input type="text" name="gr_notep" id="gr_notep" value="<?php echo get_option('gr_notep'); ?>" style="width: 80px;" /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top">Skip Standalone Notes [<a href="#" onclick="alert('Google Reader lets you add standalone notes to your shared items feed that are not attached to any feed item. Checking this box allows you to skip these items in the output.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 10px;"><input type="checkbox" name="gr_skipnote" id="gr_skipnote"<?php if (get_option('gr_skipnote')) { echo ' checked="true"'; } ?> /></td>
				</tr>
			</table>
		</div>
	</div>
	
	<div class="postbox" style="width: 350px;">
		<h3 class="hndle">Display on page / post (shortcode)</h3>
		<div class="inside">
			<p>You can display your Google Reader shared items on a dedicated page or post by simply typing <strong>[recreading]</strong> into the content (WordPress calls this "shortcode"). An optional attribute, 'items', can be set to the number of items you want to display; for example, <strong>[recreading items=5]</strong> to show 5 shared items.</p>
			<p>The shortcode will use the settings above, but also has a few additional settings you can control.</p>  
			
			<table class="form-table">
				
				<tr valign="top">
					<th scope="row" valign="top"><strong>As of publish date</strong> [<a href="#" onclick="alert('By default, the output will always be based on the latest shared items. This is ideal if you have a dedicated page for your shared items feed. However, if you will be regularly creating a post to highlight recent shared items, you will probably want to show the latest items from the date the post was published. Check this box to apply that logic. Note that this plugin caches the shared items for performance reasons. If you update your notes or the posts themselves are updated, you will need to update the post or page with the shortcode to see the changes. Setting changes made here will automatically flush the cache.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 10px;"><input type="checkbox" name="gr_publish_date" id="gr_publish_date"<?php if (get_option('gr_publish_date')) { echo ' checked="true"'; } ?> /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top" style="padding-top: 0;">... <em>up to last post</em> [<a href="#" onclick="alert('If you regularly share your items in a post, you may want to automatically show all shared items since the last post to use [recreading]. Check this option to show all shared items up until the publish date of the last post that has the [recreading] shortcode. Note that this will always override a specified number of posts, with the exception of the very first post to use the shortcode.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 0;"><input type="checkbox" name="gr_publish_upto" id="gr_publish_upto"<?php if (get_option('gr_publish_upto')) { echo ' checked="true"'; } ?> /></td>
				</tr>
			
				<tr valign="top">
					<th scope="row" valign="top">Don't truncate content [<a href="#" onclick="alert('You can override the trim setting above just for shortcode content.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 10px;"><input type="checkbox" name="gr_sc_trim" id="gr_sc_trim"<?php if (get_option('gr_sc_trim')) { echo ' checked="true"'; } ?> /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top" style="padding-top: 0;">... <em>and</em> show HTML [<a href="#" onclick="alert('The widget will strip all HTML out of the shared item content, including line and paragraph breaks. You may choose to allow HTML in shortcode output by checking this box. Note that you must also check the Don't Trim box above.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 0;"><input type="checkbox" name="gr_sc_html" id="gr_sc_html"<?php if (get_option('gr_sc_html')) { echo ' checked="true"'; } ?> /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top" style="padding-top: 0;">... ... <em>but</em> only simple tags [<a href="#" onclick="alert('Only allow very basic HTML: line breaks, paragraph breaks, bold tags, italic tags, links, and blockquotes.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 0;"><input type="checkbox" name="gr_sc_simplehtml" id="gr_sc_simplehtml"<?php if (get_option('gr_sc_simplehtml')) { echo ' checked="true"'; } ?> /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top" style="padding-top: 0;">... ... <em>and</em> hide images [<a href="#" onclick="alert('Many websites use styles to position their images in ways that will not come over with the feed content, resulting in odd image placement. Check this box to allow full HTML with the exception of images in the item content.'); return false;" style="cursor: help;">?</a>]</th>
					<td style="padding-top: 0;"><input type="checkbox" name="gr_sc_strpimg" id="gr_sc_strpimg"<?php if (get_option('gr_sc_strpimg')) { echo ' checked="true"'; } ?> /></td>
				</tr>
				<tr valign="top">
					<th scope="row" valign="top">Use special styles [<a href="#" onclick="alert('For best visual results, we recommend you consult a stylesheet developer to modify your theme and give the output a professional look. Our company (C Murray Consulting) can provide such services. If you do not want to invest time or money, you can try our included stylesheet, but your mileage may vary.'); return false;" style="cursor: help;">?</a>]</th>
					<td><input type="checkbox" name="gr_sc_styles" id="gr_sc_styles"<?php if (get_option('gr_sc_styles')) { echo ' checked="true"'; } ?> /></td>
				</tr>
			</table>
		</div>
	</div>
	
	</div>
	
	<input type="hidden" name="action" value="update" />
	<input type="hidden" name="page_options" value="gr_credit,gr_sid,gr_num,gr_content,gr_trim,gr_notes,gr_date,gr_datep,gr_source,gr_sourcep,gr_open,gr_notep,gr_skipnote,gr_sc_styles,gr_sc_html,gr_sc_trim,gr_sc_strpimg,gr_sc_simplehtml,gr_nofollow,gr_publish_date,gr_publish_upto" />
	
	<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" /></p>
	
	</form>
	</div>
  
<?php 
	} 

//***********************//
//** SHORT CODE SUPPORT *//
//***********************//

// [recreading]
function grs_shortcode($atts) {
	extract(shortcode_atts(array('items' => ''),$atts));
	return google_reader_items(true, $atts['items']);
}
add_shortcode('recreading', 'grs_shortcode');

//clear the shortcode cache, if applicable
function clear_gr_sc_cache($post_ID) {
	delete_post_meta($post_ID,"_gr_cache");
}
add_action('save_post','clear_gr_sc_cache');

function grs_stylize() {
	if(get_option('gr_sc_styles') && (is_singular() || is_home() || is_archive())) 
		echo '<link rel="stylesheet" href="'.WP_PLUGIN_URL.'/'.basename(dirname(__FILE__)).'/css/recreading.css" type="text/css" media="all" />'."\n";
}
add_action('wp_head', 'grs_stylize');


// SETTINGS LINK
function gr_plugin_actlinks( $links ) { 
 // Add a link to this plugin's settings page
 $plugin = plugin_basename(__FILE__);
 $settings_link = sprintf( '<a href="options-general.php?page=%s">%s</a>', $plugin, __('Settings') ); 
 array_unshift( $links, $settings_link ); 
 return $links; 
}
if(is_admin()) add_filter("plugin_action_links_".$plugin, 'gr_plugin_actlinks' );

//backwards compatibility for calling in template
function google_reader_shared($isshortcode = false) {
	echo google_reader_items($isshortcode);
	return true;
}
?>